contexttools.ClefMarkInventory
==============================

.. abjad-lineage:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory

.. autoclass:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.append
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.count
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.extend
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.index
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.insert
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.pop
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.remove
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.reverse
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.sort
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__add__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__delslice__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__getslice__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__imul__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__len__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__mul__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__rmul__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__setitem__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__setslice__
   :noindex:
